==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/KafkaConnectS2IFluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.strimzi.api.kafka.model.status.KafkaConnectS2IstatusBuilder;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.status.KafkaConnectS2Istatus;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.strimzi.api.kafka.model.status.KafkaConnectS2IstatusFluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaConnectS2IFluent<A extends KafkaConnectS2IFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> withNewMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaConnectS2IFluent.MetadataNested<A> editMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectS2ISpec getSpec();
    public KafkaConnectS2ISpec buildSpec();
    public A withSpec(KafkaConnectS2ISpec spec);
    public Boolean hasSpec();
    public KafkaConnectS2IFluent.SpecNested<A> withNewSpec();
    public KafkaConnectS2IFluent.SpecNested<A> withNewSpecLike(KafkaConnectS2ISpec item);
    public KafkaConnectS2IFluent.SpecNested<A> editSpec();
    public KafkaConnectS2IFluent.SpecNested<A> editOrNewSpec();
    public KafkaConnectS2IFluent.SpecNested<A> editOrNewSpecLike(KafkaConnectS2ISpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectS2Istatus getStatus();
    public KafkaConnectS2Istatus buildStatus();
    public A withStatus(KafkaConnectS2Istatus status);
    public Boolean hasStatus();
    public KafkaConnectS2IFluent.StatusNested<A> withNewStatus();
    public KafkaConnectS2IFluent.StatusNested<A> withNewStatusLike(KafkaConnectS2Istatus item);
    public KafkaConnectS2IFluent.StatusNested<A> editStatus();
    public KafkaConnectS2IFluent.StatusNested<A> editOrNewStatus();
    public KafkaConnectS2IFluent.StatusNested<A> editOrNewStatusLike(KafkaConnectS2Istatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaConnectS2IFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectS2ISpecFluent<KafkaConnectS2IFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectS2IstatusFluent<KafkaConnectS2IFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/KafkaConnectS2IFluent.java <==
package io.strimzi.api.kafka.model;

import io.strimzi.api.kafka.model.status.KafkaConnectS2IStatus;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.strimzi.api.kafka.model.status.KafkaConnectS2IStatusBuilder;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.strimzi.api.kafka.model.status.KafkaConnectS2IStatusFluent;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaConnectS2IFluent<A extends KafkaConnectS2IFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> withNewMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaConnectS2IFluent.MetadataNested<A> editMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaConnectS2IFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectS2ISpec getSpec();
    public KafkaConnectS2ISpec buildSpec();
    public A withSpec(KafkaConnectS2ISpec spec);
    public Boolean hasSpec();
    public KafkaConnectS2IFluent.SpecNested<A> withNewSpec();
    public KafkaConnectS2IFluent.SpecNested<A> withNewSpecLike(KafkaConnectS2ISpec item);
    public KafkaConnectS2IFluent.SpecNested<A> editSpec();
    public KafkaConnectS2IFluent.SpecNested<A> editOrNewSpec();
    public KafkaConnectS2IFluent.SpecNested<A> editOrNewSpecLike(KafkaConnectS2ISpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectS2IStatus getStatus();
    public KafkaConnectS2IStatus buildStatus();
    public A withStatus(KafkaConnectS2IStatus status);
    public Boolean hasStatus();
    public KafkaConnectS2IFluent.StatusNested<A> withNewStatus();
    public KafkaConnectS2IFluent.StatusNested<A> withNewStatusLike(KafkaConnectS2IStatus item);
    public KafkaConnectS2IFluent.StatusNested<A> editStatus();
    public KafkaConnectS2IFluent.StatusNested<A> editOrNewStatus();
    public KafkaConnectS2IFluent.StatusNested<A> editOrNewStatusLike(KafkaConnectS2IStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaConnectS2IFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectS2ISpecFluent<KafkaConnectS2IFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectS2IStatusFluent<KafkaConnectS2IFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
